@@ -63,7 +63,7 @@ def _action_make_post(
     # Upload the image if it's been specified.
     if jpg_path is not None:
         # Assert file has jpeg extension.
-        assert jpg_path.lower().endswith(".jpg")
+        assert jpg_path.lower().endswith(".jpg"), f"{__file__}: {jpg_path} is not a jpeg file."
         # Copy the image to the clipboard and then paste it into the post.
         if "http" in jpg_path:
             # download the image url to a local temp file and then put it on the clipboard.
@@ -86,9 +86,7 @@ def _action_make_post(
             try:
                 # Wait for the image to upload.
                 # Find the element with the xpath that includes an image source
-                driver.find_element_by_xpath(
-                    '//img[contains(@src, "media_attachments")]'
-                )
+                driver.find_element_by_xpath('//img[contains(@src, "media_attachments")]')
                 break
             except Exception:  # pylint: disable=broad-except
                 if time.time() > timeout:
@@ -107,6 +105,8 @@ def _action_make_post(
     actions.click()
     if not dry_run:
         actions.perform()
+    # Give 2 seconds for the post to succeed. Otherwise it can sometimes fail.
+    time.sleep(2)
 
 
 def gab_post(
